# secp256k1 lib support for windowsOS, macOS, linux

This is exact lib from secp256k1-py but with multi OS support.

You'll need to install `setuptools` for installation.

## INSTALL

```python
# in the repo folder
pip3 install .
```
OR

```python
# in the repo folder
python3 setup.py install
```
